from django.http import JsonResponse
import json
import datetime
# from skg.common. import *

def myconverter(o):
    if isinstance(o, datetime.datetime):
        return o.__str__()


class JSON:
    @staticmethod
    def parse(jsonStr):
        return json.loads(jsonStr)
    @staticmethod
    def dumps(jsonObj):
        
        return json.dumps(jsonObj ,default=myconverter)
    
    
class Response:
    def __init__(self):
        self.data = {"message":[],"type":"success","extra":None}
        
    def success(self,message):
        self.data["type"]="success"
        
        self.data["message"].append({"text":message,"code":""})
        
    def error(self,message,errorcode=""):
        self.data["type"]="error"
        self.data["message"].append({"text":message,"code":errorcode})
        
    def jsonResponse(self):
        return JsonResponse(self.data)
    def setExtra(self,data):
        self.data["extra"] = data
    
class DateFormats:
    
    @staticmethod
    def diff_in_ago(d):
        
        n = datetime.datetime.now()
        dt = n.replace(tzinfo=datetime.timezone.utc) - d.replace(tzinfo=datetime.timezone.utc)
        
        
        out = ""
        if d==n:
            return "Just now"
        
        
        if(dt.days!=0):
            out = str(dt.days)+" ago"
        elif (dt.seconds!=0):
            h = int(dt.seconds/3600)
            if h>0:
                out = str(h)+" hour ago"
            else:
                m = int(dt.seconds/60)
                if m >0:
                    out = str(m)+" minut ago"
                else:
                    out = "Just now"
        
        return out
        


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()


setuptools.setup(
     name='gsk',  
     version='1.0.1',
     scripts=['gsk_script'] ,
     author="Shravan Kumar Gautam",
     author_email="shravan.gautam@gmail.com",
     description="A Library set of rapid application development",
     long_description=long_description,
     long_description_content_type="text/markdown",
     url="",
     classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
     ],
     packages=[
	"gsk",
     ],
     license="MIT",
     include_package_data=True,
     install_requires=[
	"Jinja2",
	"cx_Oracle",
	"simplejson",
	"pymysql",
	"websockets",
	"websocket",
	"pyperclip",
	"flufl.bounce",
	"lambda",
	"requests",
	"python-magic"
     ]
 )
